@@ -721,7 +721,8 @@ CREATE TABLE parted_tab_part3 PARTITION OF parted_tab
 FOR VALUES IN (3);
 
 INSERT INTO parted_tab
-    VALUES (1, 'a'),
+VALUES
+    (1, 'a'),
     (2, 'a'),
     (3, 'a');
 
@@ -754,7 +755,8 @@ ORDER BY
 TRUNCATE parted_tab;
 
 INSERT INTO parted_tab
-    VALUES (1, 'a'),
+VALUES
+    (1, 'a'),
     (2, 'a'),
     (3, 'a');
 
@@ -819,7 +821,8 @@ CREATE TABLE mlparted_tab_part2b PARTITION OF mlparted_tab_part2
 FOR VALUES IN ('b');
 
 INSERT INTO mlparted_tab
-    VALUES (1, 'a'),
+VALUES
+    (1, 'a'),
     (2, 'a'),
     (2, 'b'),
     (3, 'a');
@@ -1588,7 +1591,8 @@ CREATE TABLE inh_fk_1 (
 );
 
 INSERT INTO inh_fk_1
-    VALUES (1),
+VALUES
+    (1),
     (2),
     (3);
 
@@ -1598,7 +1602,8 @@ CREATE TABLE inh_fk_2 (
 );
 
 INSERT INTO inh_fk_2
-    VALUES (11, 1),
+VALUES
+    (11, 1),
     (22, 2),
     (33, 3);
 
@@ -1608,7 +1613,8 @@ INHERITS (
 );
 
 INSERT INTO inh_fk_2_child
-    VALUES (111, 1),
+VALUES
+    (111, 1),
     (222, 2);
 
 DELETE FROM inh_fk_1
