@@ -51,7 +51,8 @@ FROM
 -- VALUES test
 --
 INSERT INTO inserttest
-    VALUES (10, 20, '40'),
+VALUES
+    (10, 20, '40'),
     (-1, 2, DEFAULT),
     ((
             SELECT
@@ -104,7 +105,8 @@ INSERT INTO inserttest (f2[1], f2[2])
     VALUES (1, 2);
 
 INSERT INTO inserttest (f2[1], f2[2])
-    VALUES (3, 4),
+VALUES
+    (3, 4),
     (5, 6);
 
 INSERT INTO inserttest (f2[1], f2[2])
@@ -120,7 +122,8 @@ INSERT INTO inserttest (f3.if1, f3.if2)
     VALUES (1, ARRAY['foo']);
 
 INSERT INTO inserttest (f3.if1, f3.if2)
-    VALUES (1, '{foo}'),
+VALUES
+    (1, '{foo}'),
     (2, '{bar}');
 
 INSERT INTO inserttest (f3.if1, f3.if2)
@@ -136,7 +139,8 @@ INSERT INTO inserttest (f3.if2[1], f3.if2[2])
     VALUES ('foo', 'bar');
 
 INSERT INTO inserttest (f3.if2[1], f3.if2[2])
-    VALUES ('foo', 'bar'),
+VALUES
+    ('foo', 'bar'),
     ('baz', 'quux');
 
 INSERT INTO inserttest (f3.if2[1], f3.if2[2])
@@ -148,7 +152,8 @@ INSERT INTO inserttest (f4[1].if2[1], f4[1].if2[2])
     VALUES ('foo', 'bar');
 
 INSERT INTO inserttest (f4[1].if2[1], f4[1].if2[2])
-    VALUES ('foo', 'bar'),
+VALUES
+    ('foo', 'bar'),
     ('baz', 'quux');
 
 INSERT INTO inserttest (f4[1].if2[1], f4[1].if2[2])
@@ -175,8 +180,9 @@ CREATE RULE irule1 AS ON INSERT TO inserttest2
 CREATE RULE irule2 AS ON INSERT TO inserttest2
     DO ALSO
     INSERT INTO inserttest (f4[1].if1, f4[1].if2[2])
-    VALUES (1, 'fool'),
-    (NEW.f1, NEW.f2);
+    VALUES
+        (1, 'fool'),
+        (NEW.f1, NEW.f2);
 
 CREATE RULE irule3 AS ON INSERT TO inserttest2
     DO ALSO
@@ -480,7 +486,8 @@ FOR VALUES FROM (25) TO (30);
 TRUNCATE list_parted;
 
 INSERT INTO list_parted
-    VALUES ('aa'),
+VALUES
+    ('aa'),
     ('cc');
 
 INSERT INTO list_parted
@@ -570,7 +577,8 @@ INSERT INTO hash_parted
 
 -- direct insert of values divisible by 4 - ok;
 INSERT INTO hpart0
-    VALUES (12),
+VALUES
+    (12),
     (16);
 
 -- fail;
@@ -1285,7 +1293,8 @@ ALTER TABLE donothingbrtrig_test ATTACH PARTITION donothingbrtrig_test2
 FOR VALUES IN (2);
 
 INSERT INTO donothingbrtrig_test
-    VALUES (1, 'foo'),
+VALUES
+    (1, 'foo'),
     (2, 'bar');
 
 SELECT
@@ -1352,7 +1361,8 @@ MAXVALUE);
 \d+ mcrparted7_gt_common_lt_d
 \d+ mcrparted8_ge_d
 INSERT INTO mcrparted
-    VALUES ('aaa', 0),
+VALUES
+    ('aaa', 0),
     ('b', 0),
     ('bz', 10),
     ('c', -10),
