@@ -245,7 +245,8 @@ ON CONFLICT (key, key, key)
 
 -- Succeed, since multi-assignment does not involve subquery:
 INSERT INTO insertconflicttest
-    VALUES (1, 'Apple'),
+VALUES
+    (1, 'Apple'),
     (2, 'Orange')
 ON CONFLICT (key)
     DO UPDATE SET
@@ -1056,7 +1057,8 @@ CREATE TABLE selfconflict (
 
 BEGIN TRANSACTION ISOLATION level read COMMITTED;
 INSERT INTO selfconflict
-    VALUES (1, 1),
+VALUES
+    (1, 1),
     (1, 2)
 ON CONFLICT
     DO NOTHING;
@@ -1064,7 +1066,8 @@ COMMIT;
 
 BEGIN TRANSACTION ISOLATION level REPEATABLE read;
 INSERT INTO selfconflict
-    VALUES (2, 1),
+VALUES
+    (2, 1),
     (2, 2)
 ON CONFLICT
     DO NOTHING;
@@ -1072,7 +1075,8 @@ COMMIT;
 
 BEGIN TRANSACTION ISOLATION level SERIALIZABLE;
 INSERT INTO selfconflict
-    VALUES (3, 1),
+VALUES
+    (3, 1),
     (3, 2)
 ON CONFLICT
     DO NOTHING;
@@ -1080,7 +1084,8 @@ COMMIT;
 
 BEGIN TRANSACTION ISOLATION level read COMMITTED;
 INSERT INTO selfconflict
-    VALUES (4, 1),
+VALUES
+    (4, 1),
     (4, 2)
 ON CONFLICT (f1)
     DO UPDATE SET
@@ -1089,7 +1094,8 @@ COMMIT;
 
 BEGIN TRANSACTION ISOLATION level REPEATABLE read;
 INSERT INTO selfconflict
-    VALUES (5, 1),
+VALUES
+    (5, 1),
     (5, 2)
 ON CONFLICT (f1)
     DO UPDATE SET
@@ -1098,7 +1104,8 @@ COMMIT;
 
 BEGIN TRANSACTION ISOLATION level SERIALIZABLE;
 INSERT INTO selfconflict
-    VALUES (6, 1),
+VALUES
+    (6, 1),
     (6, 2)
 ON CONFLICT (f1)
     DO UPDATE SET
@@ -1274,7 +1281,8 @@ ORDER BY
 TRUNCATE parted_conflict_test;
 
 INSERT INTO parted_conflict_test (a, b)
-    VALUES (1, 'a'),
+VALUES
+    (1, 'a'),
     (2, 'a'),
     (4, 'a')
 ON CONFLICT (a)
@@ -1284,7 +1292,8 @@ ON CONFLICT (a)
         excluded.b = 'b';
 
 INSERT INTO parted_conflict_test (a, b)
-    VALUES (1, 'b'),
+VALUES
+    (1, 'b'),
     (2, 'c'),
     (4, 'b')
 ON CONFLICT (a)
