@@ -145,7 +145,8 @@ CREATE TEMP TABLE INTERVAL_TBL_OF (
 );
 
 INSERT INTO INTERVAL_TBL_OF (f1)
-    VALUES ('2147483647 days 2147483647 months'),
+VALUES
+    ('2147483647 days 2147483647 months'),
     ('2147483647 days -2147483648 months'),
     ('1 year'),
     ('-2147483648 days 2147483647 months'),
