@@ -1,62 +1,62 @@
 SELECT
-    jsonb '{"a": 12}' @ ? '$';
+    jsonb '{"a": 12}' @? '$';
 
 SELECT
-    jsonb '{"a": 12}' @ ? '1';
+    jsonb '{"a": 12}' @? '1';
 
 SELECT
-    jsonb '{"a": 12}' @ ? '$.a.b';
+    jsonb '{"a": 12}' @? '$.a.b';
 
 SELECT
-    jsonb '{"a": 12}' @ ? '$.b';
+    jsonb '{"a": 12}' @? '$.b';
 
 SELECT
-    jsonb '{"a": 12}' @ ? '$.a + 2';
+    jsonb '{"a": 12}' @? '$.a + 2';
 
 SELECT
-    jsonb '{"a": 12}' @ ? '$.b + 2';
+    jsonb '{"a": 12}' @? '$.b + 2';
 
 SELECT
-    jsonb '{"a": {"a": 12}}' @ ? '$.a.a';
+    jsonb '{"a": {"a": 12}}' @? '$.a.a';
 
 SELECT
-    jsonb '{"a": {"a": 12}}' @ ? '$.*.a';
+    jsonb '{"a": {"a": 12}}' @? '$.*.a';
 
 SELECT
-    jsonb '{"b": {"a": 12}}' @ ? '$.*.a';
+    jsonb '{"b": {"a": 12}}' @? '$.*.a';
 
 SELECT
-    jsonb '{"b": {"a": 12}}' @ ? '$.*.b';
+    jsonb '{"b": {"a": 12}}' @? '$.*.b';
 
 SELECT
-    jsonb '{"b": {"a": 12}}' @ ? 'strict $.*.b';
+    jsonb '{"b": {"a": 12}}' @? 'strict $.*.b';
 
 SELECT
-    jsonb '{}' @ ? '$.*';
+    jsonb '{}' @? '$.*';
 
 SELECT
-    jsonb '{"a": 1}' @ ? '$.*';
+    jsonb '{"a": 1}' @? '$.*';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? 'lax $.**{1}';
+    jsonb '{"a": {"b": 1}}' @? 'lax $.**{1}';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? 'lax $.**{2}';
+    jsonb '{"a": {"b": 1}}' @? 'lax $.**{2}';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? 'lax $.**{3}';
+    jsonb '{"a": {"b": 1}}' @? 'lax $.**{3}';
 
 SELECT
-    jsonb '[]' @ ? '$[*]';
+    jsonb '[]' @? '$[*]';
 
 SELECT
-    jsonb '[1]' @ ? '$[*]';
+    jsonb '[1]' @? '$[*]';
 
 SELECT
-    jsonb '[1]' @ ? '$[1]';
+    jsonb '[1]' @? '$[1]';
 
 SELECT
-    jsonb '[1]' @ ? 'strict $[1]';
+    jsonb '[1]' @? 'strict $[1]';
 
 SELECT
     jsonb_path_query('[1]', 'strict $[1]');
@@ -65,10 +65,10 @@ SELECT
     jsonb_path_query('[1]', 'strict $[1]', silent => TRUE);
 
 SELECT
-    jsonb '[1]' @ ? 'lax $[10000000000000000]';
+    jsonb '[1]' @? 'lax $[10000000000000000]';
 
 SELECT
-    jsonb '[1]' @ ? 'strict $[10000000000000000]';
+    jsonb '[1]' @? 'strict $[10000000000000000]';
 
 SELECT
     jsonb_path_query('[1]', 'lax $[10000000000000000]');
@@ -77,66 +77,58 @@ SELECT
     jsonb_path_query('[1]', 'strict $[10000000000000000]');
 
 SELECT
-    jsonb '[1]' @ ? '$[0]';
+    jsonb '[1]' @? '$[0]';
 
 SELECT
-    jsonb '[1]' @ ? '$[0.3]';
+    jsonb '[1]' @? '$[0.3]';
 
 SELECT
-    jsonb '[1]' @ ? '$[0.5]';
+    jsonb '[1]' @? '$[0.5]';
 
 SELECT
-    jsonb '[1]' @ ? '$[0.9]';
+    jsonb '[1]' @? '$[0.9]';
 
 SELECT
-    jsonb '[1]' @ ? '$[1.2]';
+    jsonb '[1]' @? '$[1.2]';
 
 SELECT
-    jsonb '[1]' @ ? 'strict $[1.2]';
+    jsonb '[1]' @? 'strict $[1.2]';
 
 SELECT
-    jsonb '{"a": [1,2,3], "b": [3,4,5]}' @ ? '$ ? (@.a[*] >  @.b[*])';
+    jsonb '{"a": [1,2,3], "b": [3,4,5]}' @? '$ ? (@.a[*] >  @.b[*])';
 
 SELECT
-    jsonb '{"a": [1,2,3], "b": [3,4,5]}' @ ? '$ ? (@.a[*] >= @.b[*])';
+    jsonb '{"a": [1,2,3], "b": [3,4,5]}' @? '$ ? (@.a[*] >= @.b[*])';
 
 SELECT
-    jsonb '{"a": [1,2,3], "b": [3,4,"5"]}' @ ? '$ ? (@.a[*] >= @.b[*])';
+    jsonb '{"a": [1,2,3], "b": [3,4,"5"]}' @? '$ ? (@.a[*] >= @.b[*])';
 
 SELECT
-    jsonb '{"a": [1,2,3], "b": [3,4,"5"]}' @ ? 'strict $ ? (@.a[*] >= @.b[*])';
+    jsonb '{"a": [1,2,3], "b": [3,4,"5"]}' @? 'strict $ ? (@.a[*] >= @.b[*])';
 
 SELECT
-    jsonb '{"a": [1,2,3], "b": [3,4,null]}' @ ? '$ ? (@.a[*] >= @.b[*])';
+    jsonb '{"a": [1,2,3], "b": [3,4,null]}' @? '$ ? (@.a[*] >= @.b[*])';
 
 SELECT
-    jsonb '1' @ ? '$ ? ((@ == "1") is unknown)';
+    jsonb '1' @? '$ ? ((@ == "1") is unknown)';
 
 SELECT
-    jsonb '1' @ ? '$ ? ((@ == 1) is unknown)';
+    jsonb '1' @? '$ ? ((@ == 1) is unknown)';
 
 SELECT
-    jsonb '[{"a": 1}, {"a": 2}]' @ ? '$[0 to 1] ? (@.a > 1)';
+    jsonb '[{"a": 1}, {"a": 2}]' @? '$[0 to 1] ? (@.a > 1)';
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}, 3]',
-        'lax $[*].a',
-        silent => FALSE);
+    jsonb_path_exists('[{"a": 1}, {"a": 2}, 3]', 'lax $[*].a', silent => FALSE);
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}, 3]',
-        'lax $[*].a',
-        silent => TRUE);
+    jsonb_path_exists('[{"a": 1}, {"a": 2}, 3]', 'lax $[*].a', silent => TRUE);
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}, 3]',
-        'strict $[*].a',
-        silent => FALSE);
+    jsonb_path_exists('[{"a": 1}, {"a": 2}, 3]', 'strict $[*].a', silent => FALSE);
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}, 3]',
-        'strict $[*].a',
-        silent => TRUE);
+    jsonb_path_exists('[{"a": 1}, {"a": 2}, 3]', 'strict $[*].a', silent => TRUE);
 
 SELECT
     jsonb_path_query('1', 'lax $.a');
@@ -437,43 +429,43 @@ SELECT
     jsonb_path_query('{"a": {"c": {"b": 1}}}', 'lax $.**{2 to 3}.b ? (@ > 0)');
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? '$.**.b ? ( @ > 0)';
+    jsonb '{"a": {"b": 1}}' @? '$.**.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? '$.**{0}.b ? ( @ > 0)';
+    jsonb '{"a": {"b": 1}}' @? '$.**{0}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? '$.**{1}.b ? ( @ > 0)';
+    jsonb '{"a": {"b": 1}}' @? '$.**{1}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? '$.**{0 to last}.b ? ( @ > 0)';
+    jsonb '{"a": {"b": 1}}' @? '$.**{0 to last}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? '$.**{1 to last}.b ? ( @ > 0)';
+    jsonb '{"a": {"b": 1}}' @? '$.**{1 to last}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"b": 1}}' @ ? '$.**{1 to 2}.b ? ( @ > 0)';
+    jsonb '{"a": {"b": 1}}' @? '$.**{1 to 2}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**{0}.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**{0}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**{1}.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**{1}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**{0 to last}.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**{0 to last}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**{1 to last}.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**{1 to last}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**{1 to 2}.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**{1 to 2}.b ? ( @ > 0)';
 
 SELECT
-    jsonb '{"a": {"c": {"b": 1}}}' @ ? '$.**{2 to 3}.b ? ( @ > 0)';
+    jsonb '{"a": {"c": {"b": 1}}}' @? '$.**{2 to 3}.b ? ( @ > 0)';
 
 SELECT
     jsonb_path_query('{"g": {"x": 2}}', '$.g ? (exists (@.x))');
@@ -510,8 +502,8 @@ SELECT
     x,
     y,
     jsonb_path_query('[true, false, null]', '$[*] ? (@ == true  &&  ($x == true && $y == true) ||
- 				 @ == false && !($x == true && $y == true) ||
- 				 @ == null  &&  ($x == true && $y == true) is unknown)', jsonb_build_object('x', x, 'y', y)) AS "x && y"
+				 @ == false && !($x == true && $y == true) ||
+				 @ == null  &&  ($x == true && $y == true) is unknown)', jsonb_build_object('x', x, 'y', y)) AS "x && y"
 FROM (
     VALUES (jsonb 'true'),
         ('false'),
@@ -523,8 +515,8 @@ SELECT
     x,
     y,
     jsonb_path_query('[true, false, null]', '$[*] ? (@ == true  &&  ($x == true || $y == true) ||
- 				 @ == false && !($x == true || $y == true) ||
- 				 @ == null  &&  ($x == true || $y == true) is unknown)', jsonb_build_object('x', x, 'y', y)) AS "x || y"
+				 @ == false && !($x == true || $y == true) ||
+				 @ == null  &&  ($x == true || $y == true) is unknown)', jsonb_build_object('x', x, 'y', y)) AS "x || y"
 FROM (
     VALUES (jsonb 'true'),
         ('false'),
@@ -533,25 +525,25 @@ FROM (
         VALUES (jsonb 'true'), ('false'), ('"null"')) y (y);
 
 SELECT
-    jsonb '{"a": 1, "b":1}' @ ? '$ ? (@.a == @.b)';
+    jsonb '{"a": 1, "b":1}' @? '$ ? (@.a == @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 1, "b":1}}' @ ? '$ ? (@.a == @.b)';
+    jsonb '{"c": {"a": 1, "b":1}}' @? '$ ? (@.a == @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 1, "b":1}}' @ ? '$.c ? (@.a == @.b)';
+    jsonb '{"c": {"a": 1, "b":1}}' @? '$.c ? (@.a == @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 1, "b":1}}' @ ? '$.c ? ($.c.a == @.b)';
+    jsonb '{"c": {"a": 1, "b":1}}' @? '$.c ? ($.c.a == @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 1, "b":1}}' @ ? '$.* ? (@.a == @.b)';
+    jsonb '{"c": {"a": 1, "b":1}}' @? '$.* ? (@.a == @.b)';
 
 SELECT
-    jsonb '{"a": 1, "b":1}' @ ? '$.** ? (@.a == @.b)';
+    jsonb '{"a": 1, "b":1}' @? '$.** ? (@.a == @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 1, "b":1}}' @ ? '$.** ? (@.a == @.b)';
+    jsonb '{"c": {"a": 1, "b":1}}' @? '$.** ? (@.a == @.b)';
 
 SELECT
     jsonb_path_query('{"c": {"a": 2, "b":1}}', '$.** ? (@.a == 1 + 1)');
@@ -566,40 +558,40 @@ SELECT
     jsonb_path_query('{"c": {"a": 2, "b":1}}', '$.** ? (@.a == (@.b + 1))');
 
 SELECT
-    jsonb '{"c": {"a": -1, "b":1}}' @ ? '$.** ? (@.a == - 1)';
+    jsonb '{"c": {"a": -1, "b":1}}' @? '$.** ? (@.a == - 1)';
 
 SELECT
-    jsonb '{"c": {"a": -1, "b":1}}' @ ? '$.** ? (@.a == -1)';
+    jsonb '{"c": {"a": -1, "b":1}}' @? '$.** ? (@.a == -1)';
 
 SELECT
-    jsonb '{"c": {"a": -1, "b":1}}' @ ? '$.** ? (@.a == -@.b)';
+    jsonb '{"c": {"a": -1, "b":1}}' @? '$.** ? (@.a == -@.b)';
 
 SELECT
-    jsonb '{"c": {"a": -1, "b":1}}' @ ? '$.** ? (@.a == - @.b)';
+    jsonb '{"c": {"a": -1, "b":1}}' @? '$.** ? (@.a == - @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 0, "b":1}}' @ ? '$.** ? (@.a == 1 - @.b)';
+    jsonb '{"c": {"a": 0, "b":1}}' @? '$.** ? (@.a == 1 - @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 2, "b":1}}' @ ? '$.** ? (@.a == 1 - - @.b)';
+    jsonb '{"c": {"a": 2, "b":1}}' @? '$.** ? (@.a == 1 - - @.b)';
 
 SELECT
-    jsonb '{"c": {"a": 0, "b":1}}' @ ? '$.** ? (@.a == 1 - +@.b)';
+    jsonb '{"c": {"a": 0, "b":1}}' @? '$.** ? (@.a == 1 - +@.b)';
 
 SELECT
-    jsonb '[1,2,3]' @ ? '$ ? (+@[*] > +2)';
+    jsonb '[1,2,3]' @? '$ ? (+@[*] > +2)';
 
 SELECT
-    jsonb '[1,2,3]' @ ? '$ ? (+@[*] > +3)';
+    jsonb '[1,2,3]' @? '$ ? (+@[*] > +3)';
 
 SELECT
-    jsonb '[1,2,3]' @ ? '$ ? (-@[*] < -2)';
+    jsonb '[1,2,3]' @? '$ ? (-@[*] < -2)';
 
 SELECT
-    jsonb '[1,2,3]' @ ? '$ ? (-@[*] < -3)';
+    jsonb '[1,2,3]' @? '$ ? (-@[*] < -3)';
 
 SELECT
-    jsonb '1' @ ? '$ ? ($ > 0)';
+    jsonb '1' @? '$ ? ($ > 0)';
 
 -- arithmetic errors
 SELECT
@@ -642,16 +634,16 @@ SELECT
     jsonb_path_query('[1,"2",3]', '+$', silent => TRUE);
 
 SELECT
-    jsonb '["1",2,0,3]' @ ? '-$[*]';
+    jsonb '["1",2,0,3]' @? '-$[*]';
 
 SELECT
-    jsonb '[1,"2",0,3]' @ ? '-$[*]';
+    jsonb '[1,"2",0,3]' @? '-$[*]';
 
 SELECT
-    jsonb '["1",2,0,3]' @ ? 'strict -$[*]';
+    jsonb '["1",2,0,3]' @? 'strict -$[*]';
 
 SELECT
-    jsonb '[1,"2",0,3]' @ ? 'strict -$[*]';
+    jsonb '[1,"2",0,3]' @? 'strict -$[*]';
 
 -- unwrapping of operator arguments in lax mode
 SELECT
@@ -681,7 +673,7 @@ SELECT
     jsonb_path_query('2', '$ == "2"');
 
 SELECT
-    jsonb '2' @ ? '$ == "2"';
+    jsonb '2' @? '$ == "2"';
 
 SELECT
     jsonb '2' @@ '$ > 1';
@@ -708,34 +700,22 @@ SELECT
     jsonb '[]' @@ '$[*]';
 
 SELECT
-    jsonb_path_match ('[[1, true], [2, false]]',
-        'strict $[*] ? (@[0] > $x) [1]',
-        '{"x": 1}');
+    jsonb_path_match('[[1, true], [2, false]]', 'strict $[*] ? (@[0] > $x) [1]', '{"x": 1}');
 
 SELECT
-    jsonb_path_match ('[[1, true], [2, false]]',
-        'strict $[*] ? (@[0] < $x) [1]',
-        '{"x": 2}');
+    jsonb_path_match('[[1, true], [2, false]]', 'strict $[*] ? (@[0] < $x) [1]', '{"x": 2}');
 
 SELECT
-    jsonb_path_match ('[{"a": 1}, {"a": 2}, 3]',
-        'lax exists($[*].a)',
-        silent => FALSE);
+    jsonb_path_match('[{"a": 1}, {"a": 2}, 3]', 'lax exists($[*].a)', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('[{"a": 1}, {"a": 2}, 3]',
-        'lax exists($[*].a)',
-        silent => TRUE);
+    jsonb_path_match('[{"a": 1}, {"a": 2}, 3]', 'lax exists($[*].a)', silent => TRUE);
 
 SELECT
-    jsonb_path_match ('[{"a": 1}, {"a": 2}, 3]',
-        'strict exists($[*].a)',
-        silent => FALSE);
+    jsonb_path_match('[{"a": 1}, {"a": 2}, 3]', 'strict exists($[*].a)', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('[{"a": 1}, {"a": 2}, 3]',
-        'strict exists($[*].a)',
-        silent => TRUE);
+    jsonb_path_match('[{"a": 1}, {"a": 2}, 3]', 'strict exists($[*].a)', silent => TRUE);
 
 SELECT
     jsonb_path_query('[null,1,true,"a",[],{}]', '$.type()');
@@ -825,10 +805,10 @@ SELECT
     jsonb_path_query('[{"a": 1, "b": [1, 2]}, {"c": {"a": "bbb"}}]', 'strict $.keyvalue().a');
 
 SELECT
-    jsonb '{"a": 1, "b": [1, 2]}' @ ? 'lax $.keyvalue()';
+    jsonb '{"a": 1, "b": [1, 2]}' @? 'lax $.keyvalue()';
 
 SELECT
-    jsonb '{"a": 1, "b": [1, 2]}' @ ? 'lax $.keyvalue().key';
+    jsonb '{"a": 1, "b": [1, 2]}' @? 'lax $.keyvalue().key';
 
 SELECT
     jsonb_path_query('null', '$.double()');
@@ -946,141 +926,94 @@ SELECT
     jsonb_path_query('[{"a": 1}, {"a": 2}]', '$[*] ? (@.a > 10)');
 
 SELECT
-    jsonb_path_query_array ('[{"a": 1}, {"a": 2}, {}]',
-        'strict $[*].a');
+    jsonb_path_query_array('[{"a": 1}, {"a": 2}, {}]', 'strict $[*].a');
 
 SELECT
-    jsonb_path_query_array ('[{"a": 1}, {"a": 2}]',
-        '$[*].a');
+    jsonb_path_query_array('[{"a": 1}, {"a": 2}]', '$[*].a');
 
 SELECT
-    jsonb_path_query_array ('[{"a": 1}, {"a": 2}]',
-        '$[*].a ? (@ == 1)');
+    jsonb_path_query_array('[{"a": 1}, {"a": 2}]', '$[*].a ? (@ == 1)');
 
 SELECT
-    jsonb_path_query_array ('[{"a": 1}, {"a": 2}]',
-        '$[*].a ? (@ > 10)');
+    jsonb_path_query_array('[{"a": 1}, {"a": 2}]', '$[*].a ? (@ > 10)');
 
 SELECT
-    jsonb_path_query_array ('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]',
-        '$[*].a ? (@ > $min && @ < $max)',
-        vars => '{"min": 1, "max": 4}');
+    jsonb_path_query_array('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]', '$[*].a ? (@ > $min && @ < $max)', vars => '{"min": 1, "max": 4}');
 
 SELECT
-    jsonb_path_query_array ('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]',
-        '$[*].a ? (@ > $min && @ < $max)',
-        vars => '{"min": 3, "max": 4}');
+    jsonb_path_query_array('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]', '$[*].a ? (@ > $min && @ < $max)', vars => '{"min": 3, "max": 4}');
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}, {}]',
-        'strict $[*].a');
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}, {}]', 'strict $[*].a');
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}, {}]',
-        'strict $[*].a',
-        silent => TRUE);
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}, {}]', 'strict $[*].a', silent => TRUE);
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}]',
-        '$[*].a');
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}]', '$[*].a');
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}]',
-        '$[*].a ? (@ == 1)');
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}]', '$[*].a ? (@ == 1)');
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}]',
-        '$[*].a ? (@ > 10)');
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}]', '$[*].a ? (@ > 10)');
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]',
-        '$[*].a ? (@ > $min && @ < $max)',
-        vars => '{"min": 1, "max": 4}');
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]', '$[*].a ? (@ > $min && @ < $max)', vars => '{"min": 1, "max": 4}');
 
 SELECT
-    jsonb_path_query_first ('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]',
-        '$[*].a ? (@ > $min && @ < $max)',
-        vars => '{"min": 3, "max": 4}');
+    jsonb_path_query_first('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]', '$[*].a ? (@ > $min && @ < $max)', vars => '{"min": 3, "max": 4}');
 
 SELECT
-    jsonb '[{"a": 1}, {"a": 2}]' @ ? '$[*].a ? (@ > 1)';
+    jsonb '[{"a": 1}, {"a": 2}]' @? '$[*].a ? (@ > 1)';
 
 SELECT
-    jsonb '[{"a": 1}, {"a": 2}]' @ ? '$[*] ? (@.a > 2)';
+    jsonb '[{"a": 1}, {"a": 2}]' @? '$[*] ? (@.a > 2)';
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}]',
-        '$[*].a ? (@ > 1)');
+    jsonb_path_exists('[{"a": 1}, {"a": 2}]', '$[*].a ? (@ > 1)');
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]',
-        '$[*] ? (@.a > $min && @.a < $max)',
-        vars => '{"min": 1, "max": 4}');
+    jsonb_path_exists('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]', '$[*] ? (@.a > $min && @.a < $max)', vars => '{"min": 1, "max": 4}');
 
 SELECT
-    jsonb_path_exists ('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]',
-        '$[*] ? (@.a > $min && @.a < $max)',
-        vars => '{"min": 3, "max": 4}');
+    jsonb_path_exists('[{"a": 1}, {"a": 2}, {"a": 3}, {"a": 5}]', '$[*] ? (@.a > $min && @.a < $max)', vars => '{"min": 3, "max": 4}');
 
 SELECT
-    jsonb_path_match ('true',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('true', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('false',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('false', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('null',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('null', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('1',
-        '$',
-        silent => TRUE);
+    jsonb_path_match('1', '$', silent => TRUE);
 
 SELECT
-    jsonb_path_match ('1',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('1', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('"a"',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('"a"', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('{}',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('{}', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('[true]',
-        '$',
-        silent => FALSE);
+    jsonb_path_match('[true]', '$', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('{}',
-        'lax $.a',
-        silent => FALSE);
+    jsonb_path_match('{}', 'lax $.a', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('{}',
-        'strict $.a',
-        silent => FALSE);
+    jsonb_path_match('{}', 'strict $.a', silent => FALSE);
 
 SELECT
-    jsonb_path_match ('{}',
-        'strict $.a',
-        silent => TRUE);
+    jsonb_path_match('{}', 'strict $.a', silent => TRUE);
 
 SELECT
-    jsonb_path_match ('[true, true]',
-        '$[*]',
-        silent => FALSE);
+    jsonb_path_match('[true, true]', '$[*]', silent => FALSE);
 
 SELECT
     jsonb '[{"a": 1}, {"a": 2}]' @@ '$[*].a > 1';
@@ -1089,6 +1022,5 @@ SELECT
     jsonb '[{"a": 1}, {"a": 2}]' @@ '$[*].a > 2';
 
 SELECT
-    jsonb_path_match ('[{"a": 1}, {"a": 2}]',
-        '$[*].a > 1');
+    jsonb_path_match('[{"a": 1}, {"a": 2}]', '$[*].a > 1');
 
