@@ -6,7 +6,8 @@ CREATE TABLE mvtest_t (
 );
 
 INSERT INTO mvtest_t
-    VALUES (1, 'x', 2),
+VALUES
+    (1, 'x', 2),
     (2, 'x', 3),
     (3, 'y', 5),
     (4, 'y', 7),
@@ -476,7 +477,8 @@ CREATE TABLE mvtest_boxes (
 );
 
 INSERT INTO mvtest_boxes (b)
-    VALUES ('(32,32),(31,31)'),
+VALUES
+    ('(32,32),(31,31)'),
     ('(2.0000004,2.0000004),(1,1)'),
     ('(1.9999996,1.9999996),(1,1)');
 
