@@ -321,8 +321,7 @@ INSERT INTO upsert_test
     VALUES (1, 'Bar')
 ON CONFLICT (a)
     DO UPDATE SET
-        (b,
-            a) = (
+        (b, a) = (
             SELECT
                 b,
                 a
@@ -336,8 +335,7 @@ INSERT INTO upsert_test
     VALUES (1, 'Baz')
 ON CONFLICT (a)
     DO UPDATE SET
-        (b,
-            a) = (
+        (b, a) = (
             SELECT
                 b || ', Correlated',
                 a
@@ -353,8 +351,7 @@ INSERT INTO upsert_test
     VALUES (1, 'Bat')
 ON CONFLICT (a)
     DO UPDATE SET
-        (b,
-            a) = (
+        (b, a) = (
             SELECT
                 b || ', Excluded',
                 a
@@ -1403,7 +1400,8 @@ CREATE TABLE non_parted (
 );
 
 INSERT INTO non_parted
-    VALUES (1),
+VALUES
+    (1),
     (1),
     (1),
     (2),
