@@ -38,8 +38,8 @@ CREATE TABLE FKTABLE (
 );
 
 CREATE TABLE FKTABLE (
-    ftest1 int DEFAULT - 1,
-    ftest2 int DEFAULT - 2,
+    ftest1 int DEFAULT -1,
+    ftest2 int DEFAULT -2,
     ftest3 int,
     CONSTRAINT constrname2 FOREIGN KEY (ftest1, ftest2) REFERENCES PKTABLE MATCH FULL ON DELETE SET DEFAULT ON UPDATE SET DEFAULT
 );
@@ -89,21 +89,21 @@ EXPLAIN (
     COSTS OFF
 ) INSERT INTO insertconflicttest
     VALUES (0, 'Crowberry')
-ON CONFLICT (fruit, KEY, fruit, KEY)
+ON CONFLICT (fruit, key, fruit, key)
     DO NOTHING;
 
 EXPLAIN (
     COSTS OFF
 ) INSERT INTO insertconflicttest
     VALUES (0, 'Crowberry')
-ON CONFLICT (lower(fruit), KEY, lower(fruit), KEY)
+ON CONFLICT (lower(fruit), key, lower(fruit), key)
     DO NOTHING;
 
 EXPLAIN (
     COSTS OFF
 ) INSERT INTO insertconflicttest
     VALUES (0, 'Crowberry')
-ON CONFLICT (KEY, fruit)
+ON CONFLICT (key, fruit)
     DO UPDATE SET
         fruit = excluded.fruit
     WHERE
@@ -139,23 +139,23 @@ DECLARE
     dummy integer;
 BEGIN
     IF tg_op = ''INSERT'' THEN
-        dummy := tg_hub_adjustslots (new.name, 0, new.nslots);
+        dummy := tg_hub_adjustslots (NEW.name, 0, NEW.nslots);
         RETURN new;
     END IF;
     IF tg_op = ''UPDATE'' THEN
-        IF new.name != old.name THEN
+        IF NEW.name != OLD.name THEN
             UPDATE
                 HSlot
             SET
-                hubname = new.name
+                hubname = NEW.name
             WHERE
-                hubname = old.name;
+                hubname = OLD.name;
         END IF;
-        dummy := tg_hub_adjustslots (new.name, old.nslots, new.nslots);
+        dummy := tg_hub_adjustslots (NEW.name, OLD.nslots, NEW.nslots);
         RETURN new;
     END IF;
     IF tg_op = ''DELETE'' THEN
-        dummy := tg_hub_adjustslots (old.name, old.nslots, 0);
+        dummy := tg_hub_adjustslots (OLD.name, OLD.nslots, 0);
         RETURN old;
     END IF;
 END;
@@ -196,29 +196,29 @@ DECLARE
     dummy integer;
 BEGIN
     IF tg_op = ''INSERT'' THEN
-        IF new.backlink != '''' THEN
-            dummy := tg_backlink_set (new.backlink, new.slotname);
+        IF NEW.backlink != '''' THEN
+            dummy := tg_backlink_set (NEW.backlink, NEW.slotname);
         END IF;
         RETURN new;
     END IF;
     IF tg_op = ''UPDATE'' THEN
-        IF new.backlink != old.backlink THEN
-            IF old.backlink != '''' THEN
-                dummy := tg_backlink_unset (old.backlink, old.slotname);
+        IF NEW.backlink != OLD.backlink THEN
+            IF OLD.backlink != '''' THEN
+                dummy := tg_backlink_unset (OLD.backlink, OLD.slotname);
             END IF;
-            IF new.backlink != '''' THEN
-                dummy := tg_backlink_set (new.backlink, new.slotname);
+            IF NEW.backlink != '''' THEN
+                dummy := tg_backlink_set (NEW.backlink, NEW.slotname);
             END IF;
         ELSE
-            IF new.slotname != old.slotname AND new.backlink != '''' THEN
-                dummy := tg_slotlink_set (new.backlink, new.slotname);
+            IF NEW.slotname != OLD.slotname AND NEW.backlink != '''' THEN
+                dummy := tg_slotlink_set (NEW.backlink, NEW.slotname);
             END IF;
         END IF;
         RETURN new;
     END IF;
     IF tg_op = ''DELETE'' THEN
-        IF old.backlink != '''' THEN
-            dummy := tg_backlink_unset (old.backlink, old.slotname);
+        IF OLD.backlink != '''' THEN
+            dummy := tg_backlink_unset (OLD.backlink, OLD.slotname);
         END IF;
         RETURN old;
     END IF;
@@ -238,3 +238,10 @@ WITH a AS (
 \set passwd `echo $PGRST_DB_PWD`
 CREATE ROLE :user WITH LOGIN noinherit PASSWORD :'passwd';
 
+SELECT
+    -11,
+    -10 * -1.3,
+    -1.3 * 10, (1 + 2) - -9,
+    ARRAY[-15, -14, -13],
+    fnsum (-12 + 34);
+
